# This file was automatically generated by SWIG (https://www.swig.org).
# Version 4.4.1
#
# Do not make changes to this file unless you know what you are doing - modify
# the SWIG interface file instead.


import collections

from sys import version_info as _version_info
if _version_info < (3, 7, 0):
    raise RuntimeError("Python 3.7 or later required")

from . import _ITKCommonPython


from . import _ITKSpatialObjectsPython



from sys import version_info as _swig_python_version_info
# Import the low-level C/C++ module
if getattr(globals().get("__spec__"), "parent", None) or __package__ or "." in __name__:
    from . import _itkTubeSpatialObjectPython
else:
    import _itkTubeSpatialObjectPython

try:
    import builtins as __builtin__
except ImportError:
    import __builtin__

def _swig_repr(self):
    try:
        strthis = "proxy of " + self.this.__repr__()
    except __builtin__.Exception:
        strthis = ""
    return "<%s.%s; %s >" % (self.__class__.__module__, self.__class__.__name__, strthis,)


def _swig_setattr_nondynamic_instance_variable(set):
    def set_instance_attr(self, name, value):
        if name == "this":
            set(self, name, value)
        elif name == "thisown":
            self.this.own(value)
        elif hasattr(self, name) and isinstance(getattr(type(self), name), property):
            set(self, name, value)
        else:
            raise AttributeError("You cannot add instance attributes to %s" % self)
    return set_instance_attr


def _swig_setattr_nondynamic_class_variable(set):
    def set_class_attr(cls, name, value):
        if hasattr(cls, name) and not isinstance(getattr(cls, name), property):
            set(cls, name, value)
        else:
            raise AttributeError("You cannot add class attributes to %s" % cls)
    return set_class_attr


def _swig_add_metaclass(metaclass):
    """Class decorator for adding a metaclass to a SWIG wrapped class - a slimmed down version of six.add_metaclass"""
    def wrapper(cls):
        return metaclass(cls.__name__, cls.__bases__, cls.__dict__.copy())
    return wrapper


class _SwigNonDynamicMeta(type):
    """Meta class to enforce nondynamic attributes (no new attributes) for a class"""
    __setattr__ = _swig_setattr_nondynamic_class_variable(type.__setattr__)


if _swig_python_version_info[0:2] >= (3, 3):
    import collections.abc
else:
    import collections

import itk.itkTubeSpatialObjectPointPython
import itk.itkCovariantVectorPython
import itk.itkVectorPython
import itk.itkFixedArrayPython
import itk.pyBasePython
import itk.vnl_vector_refPython
import itk.vnl_vectorPython
import itk.vnl_matrixPython
import itk.stdcomplexPython
import itk.ITKCommonBasePython
import itk.itkMatrixPython
import itk.itkPointPython
import itk.vnl_matrix_fixedPython
import itk.itkSpatialObjectPointPython
import itk.itkRGBAPixelPython
import itk.itkSpatialObjectBasePython
import itk.itkAffineTransformPython
import itk.itkTransformBasePython
import itk.itkDiffusionTensor3DPython
import itk.itkSymmetricSecondRankTensorPython
import itk.itkArrayPython
import itk.itkVariableLengthVectorPython
import itk.itkOptimizerParametersPython
import itk.itkArray2DPython
import itk.itkMatrixOffsetTransformBasePython
import itk.itkSpatialObjectPropertyPython
import itk.itkImageRegionPython
import itk.itkIndexPython
import itk.itkOffsetPython
import itk.itkSizePython
import itk.itkBoundingBoxPython
import itk.itkMapContainerPython
import itk.itkVectorContainerPython
import itk.itkContinuousIndexPython
class listitkPointBasedSpatialObjectTube2_Pointer(collections.abc.MutableSequence if _swig_python_version_info >= (3, 3) else collections.MutableSequence):
    r"""Proxy of C++ std::list< itkPointBasedSpatialObjectTube2_Pointer > class."""

    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def iterator(self):
        r"""iterator(self) -> SwigPyIterator"""
        return _itkTubeSpatialObjectPython.listitkPointBasedSpatialObjectTube2_Pointer_iterator(self)
    def __iter__(self):
        return self.iterator()

    def __nonzero__(self):
        r"""__nonzero__(self) -> bool"""
        return _itkTubeSpatialObjectPython.listitkPointBasedSpatialObjectTube2_Pointer___nonzero__(self)

    def __bool__(self):
        r"""__bool__(self) -> bool"""
        return _itkTubeSpatialObjectPython.listitkPointBasedSpatialObjectTube2_Pointer___bool__(self)

    def __len__(self):
        r"""__len__(self) -> std::list< itkPointBasedSpatialObjectTube2_Pointer >::size_type"""
        return _itkTubeSpatialObjectPython.listitkPointBasedSpatialObjectTube2_Pointer___len__(self)

    def __getslice__(self, i, j):
        r"""
        __getslice__(self, i, j) -> listitkPointBasedSpatialObjectTube2_Pointer

        Parameters
        ----------
        i: std::list< itkPointBasedSpatialObjectTube2_Pointer >::difference_type
        j: std::list< itkPointBasedSpatialObjectTube2_Pointer >::difference_type

        """
        return _itkTubeSpatialObjectPython.listitkPointBasedSpatialObjectTube2_Pointer___getslice__(self, i, j)

    def __setslice__(self, *args):
        r"""
        __setslice__(self, i, j)

        Parameters
        ----------
        i: std::list< itkPointBasedSpatialObjectTube2_Pointer >::difference_type
        j: std::list< itkPointBasedSpatialObjectTube2_Pointer >::difference_type

        __setslice__(self, i, j, v)

        Parameters
        ----------
        i: std::list< itkPointBasedSpatialObjectTube2_Pointer >::difference_type
        j: std::list< itkPointBasedSpatialObjectTube2_Pointer >::difference_type
        v: std::list< itkPointBasedSpatialObjectTube2_Pointer,std::allocator< itkPointBasedSpatialObjectTube2_Pointer > > const &

        """
        return _itkTubeSpatialObjectPython.listitkPointBasedSpatialObjectTube2_Pointer___setslice__(self, *args)

    def __delslice__(self, i, j):
        r"""
        __delslice__(self, i, j)

        Parameters
        ----------
        i: std::list< itkPointBasedSpatialObjectTube2_Pointer >::difference_type
        j: std::list< itkPointBasedSpatialObjectTube2_Pointer >::difference_type

        """
        return _itkTubeSpatialObjectPython.listitkPointBasedSpatialObjectTube2_Pointer___delslice__(self, i, j)

    def __delitem__(self, *args):
        r"""
        __delitem__(self, i)

        Parameters
        ----------
        i: std::list< itkPointBasedSpatialObjectTube2_Pointer >::difference_type

        __delitem__(self, slice)

        Parameters
        ----------
        slice: SWIGPY_SLICEOBJECT *

        """
        return _itkTubeSpatialObjectPython.listitkPointBasedSpatialObjectTube2_Pointer___delitem__(self, *args)

    def __getitem__(self, *args):
        r"""
        __getitem__(self, slice) -> listitkPointBasedSpatialObjectTube2_Pointer

        Parameters
        ----------
        slice: SWIGPY_SLICEOBJECT *

        __getitem__(self, i) -> std::list< itkPointBasedSpatialObjectTube2_Pointer >::value_type const &

        Parameters
        ----------
        i: std::list< itkPointBasedSpatialObjectTube2_Pointer >::difference_type

        """
        return _itkTubeSpatialObjectPython.listitkPointBasedSpatialObjectTube2_Pointer___getitem__(self, *args)

    def __setitem__(self, *args):
        r"""
        __setitem__(self, slice, v)

        Parameters
        ----------
        slice: SWIGPY_SLICEOBJECT *
        v: std::list< itkPointBasedSpatialObjectTube2_Pointer,std::allocator< itkPointBasedSpatialObjectTube2_Pointer > > const &

        __setitem__(self, slice)

        Parameters
        ----------
        slice: SWIGPY_SLICEOBJECT *

        __setitem__(self, i, x)

        Parameters
        ----------
        i: std::list< itkPointBasedSpatialObjectTube2_Pointer >::difference_type
        x: std::list< itkPointBasedSpatialObjectTube2_Pointer >::value_type const &

        """
        return _itkTubeSpatialObjectPython.listitkPointBasedSpatialObjectTube2_Pointer___setitem__(self, *args)

    def pop(self):
        r"""pop(self) -> std::list< itkPointBasedSpatialObjectTube2_Pointer >::value_type"""
        return _itkTubeSpatialObjectPython.listitkPointBasedSpatialObjectTube2_Pointer_pop(self)

    def append(self, x):
        r"""
        append(self, x)

        Parameters
        ----------
        x: std::list< itkPointBasedSpatialObjectTube2_Pointer >::value_type const &

        """
        return _itkTubeSpatialObjectPython.listitkPointBasedSpatialObjectTube2_Pointer_append(self, x)

    def empty(self):
        r"""empty(self) -> bool"""
        return _itkTubeSpatialObjectPython.listitkPointBasedSpatialObjectTube2_Pointer_empty(self)

    def size(self):
        r"""size(self) -> std::list< itkPointBasedSpatialObjectTube2_Pointer >::size_type"""
        return _itkTubeSpatialObjectPython.listitkPointBasedSpatialObjectTube2_Pointer_size(self)

    def swap(self, v):
        r"""
        swap(self, v)

        Parameters
        ----------
        v: std::list< itkPointBasedSpatialObjectTube2_Pointer > &

        """
        return _itkTubeSpatialObjectPython.listitkPointBasedSpatialObjectTube2_Pointer_swap(self, v)

    def begin(self):
        r"""begin(self) -> std::list< itkPointBasedSpatialObjectTube2_Pointer >::iterator"""
        return _itkTubeSpatialObjectPython.listitkPointBasedSpatialObjectTube2_Pointer_begin(self)

    def end(self):
        r"""end(self) -> std::list< itkPointBasedSpatialObjectTube2_Pointer >::iterator"""
        return _itkTubeSpatialObjectPython.listitkPointBasedSpatialObjectTube2_Pointer_end(self)

    def rbegin(self):
        r"""rbegin(self) -> std::list< itkPointBasedSpatialObjectTube2_Pointer >::reverse_iterator"""
        return _itkTubeSpatialObjectPython.listitkPointBasedSpatialObjectTube2_Pointer_rbegin(self)

    def rend(self):
        r"""rend(self) -> std::list< itkPointBasedSpatialObjectTube2_Pointer >::reverse_iterator"""
        return _itkTubeSpatialObjectPython.listitkPointBasedSpatialObjectTube2_Pointer_rend(self)

    def clear(self):
        r"""clear(self)"""
        return _itkTubeSpatialObjectPython.listitkPointBasedSpatialObjectTube2_Pointer_clear(self)

    def get_allocator(self):
        r"""get_allocator(self) -> std::list< itkPointBasedSpatialObjectTube2_Pointer >::allocator_type"""
        return _itkTubeSpatialObjectPython.listitkPointBasedSpatialObjectTube2_Pointer_get_allocator(self)

    def pop_back(self):
        r"""pop_back(self)"""
        return _itkTubeSpatialObjectPython.listitkPointBasedSpatialObjectTube2_Pointer_pop_back(self)

    def erase(self, *args):
        r"""
        erase(self, pos) -> std::list< itkPointBasedSpatialObjectTube2_Pointer >::iterator

        Parameters
        ----------
        pos: std::list< itkPointBasedSpatialObjectTube2_Pointer >::iterator

        erase(self, first, last) -> std::list< itkPointBasedSpatialObjectTube2_Pointer >::iterator

        Parameters
        ----------
        first: std::list< itkPointBasedSpatialObjectTube2_Pointer >::iterator
        last: std::list< itkPointBasedSpatialObjectTube2_Pointer >::iterator

        """
        return _itkTubeSpatialObjectPython.listitkPointBasedSpatialObjectTube2_Pointer_erase(self, *args)

    def __init__(self, *args):
        r"""
        __init__(self) -> listitkPointBasedSpatialObjectTube2_Pointer
        __init__(self, other) -> listitkPointBasedSpatialObjectTube2_Pointer

        Parameters
        ----------
        other: std::list< itkPointBasedSpatialObjectTube2_Pointer > const &

        __init__(self, size) -> listitkPointBasedSpatialObjectTube2_Pointer

        Parameters
        ----------
        size: std::list< itkPointBasedSpatialObjectTube2_Pointer >::size_type

        __init__(self, size, value) -> listitkPointBasedSpatialObjectTube2_Pointer

        Parameters
        ----------
        size: std::list< itkPointBasedSpatialObjectTube2_Pointer >::size_type
        value: std::list< itkPointBasedSpatialObjectTube2_Pointer >::value_type const &

        """
        _itkTubeSpatialObjectPython.listitkPointBasedSpatialObjectTube2_Pointer_swiginit(self, _itkTubeSpatialObjectPython.new_listitkPointBasedSpatialObjectTube2_Pointer(*args))

    def push_back(self, x):
        r"""
        push_back(self, x)

        Parameters
        ----------
        x: std::list< itkPointBasedSpatialObjectTube2_Pointer >::value_type const &

        """
        return _itkTubeSpatialObjectPython.listitkPointBasedSpatialObjectTube2_Pointer_push_back(self, x)

    def front(self):
        r"""front(self) -> std::list< itkPointBasedSpatialObjectTube2_Pointer >::value_type const &"""
        return _itkTubeSpatialObjectPython.listitkPointBasedSpatialObjectTube2_Pointer_front(self)

    def back(self):
        r"""back(self) -> std::list< itkPointBasedSpatialObjectTube2_Pointer >::value_type const &"""
        return _itkTubeSpatialObjectPython.listitkPointBasedSpatialObjectTube2_Pointer_back(self)

    def assign(self, n, x):
        r"""
        assign(self, n, x)

        Parameters
        ----------
        n: std::list< itkPointBasedSpatialObjectTube2_Pointer >::size_type
        x: std::list< itkPointBasedSpatialObjectTube2_Pointer >::value_type const &

        """
        return _itkTubeSpatialObjectPython.listitkPointBasedSpatialObjectTube2_Pointer_assign(self, n, x)

    def resize(self, *args):
        r"""
        resize(self, new_size)

        Parameters
        ----------
        new_size: std::list< itkPointBasedSpatialObjectTube2_Pointer >::size_type

        resize(self, new_size, x)

        Parameters
        ----------
        new_size: std::list< itkPointBasedSpatialObjectTube2_Pointer >::size_type
        x: std::list< itkPointBasedSpatialObjectTube2_Pointer >::value_type const &

        """
        return _itkTubeSpatialObjectPython.listitkPointBasedSpatialObjectTube2_Pointer_resize(self, *args)

    def insert(self, *args):
        r"""
        insert(self, pos, x) -> std::list< itkPointBasedSpatialObjectTube2_Pointer >::iterator

        Parameters
        ----------
        pos: std::list< itkPointBasedSpatialObjectTube2_Pointer >::iterator
        x: std::list< itkPointBasedSpatialObjectTube2_Pointer >::value_type const &

        insert(self, pos, n, x)

        Parameters
        ----------
        pos: std::list< itkPointBasedSpatialObjectTube2_Pointer >::iterator
        n: std::list< itkPointBasedSpatialObjectTube2_Pointer >::size_type
        x: std::list< itkPointBasedSpatialObjectTube2_Pointer >::value_type const &

        """
        return _itkTubeSpatialObjectPython.listitkPointBasedSpatialObjectTube2_Pointer_insert(self, *args)

    def pop_front(self):
        r"""pop_front(self)"""
        return _itkTubeSpatialObjectPython.listitkPointBasedSpatialObjectTube2_Pointer_pop_front(self)

    def push_front(self, x):
        r"""
        push_front(self, x)

        Parameters
        ----------
        x: std::list< itkPointBasedSpatialObjectTube2_Pointer >::value_type const &

        """
        return _itkTubeSpatialObjectPython.listitkPointBasedSpatialObjectTube2_Pointer_push_front(self, x)

    def reverse(self):
        r"""reverse(self)"""
        return _itkTubeSpatialObjectPython.listitkPointBasedSpatialObjectTube2_Pointer_reverse(self)
    __swig_destroy__ = _itkTubeSpatialObjectPython.delete_listitkPointBasedSpatialObjectTube2_Pointer

# Register listitkPointBasedSpatialObjectTube2_Pointer in _itkTubeSpatialObjectPython:
_itkTubeSpatialObjectPython.listitkPointBasedSpatialObjectTube2_Pointer_swigregister(listitkPointBasedSpatialObjectTube2_Pointer)
class listitkPointBasedSpatialObjectTube3_Pointer(collections.abc.MutableSequence if _swig_python_version_info >= (3, 3) else collections.MutableSequence):
    r"""Proxy of C++ std::list< itkPointBasedSpatialObjectTube3_Pointer > class."""

    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def iterator(self):
        r"""iterator(self) -> SwigPyIterator"""
        return _itkTubeSpatialObjectPython.listitkPointBasedSpatialObjectTube3_Pointer_iterator(self)
    def __iter__(self):
        return self.iterator()

    def __nonzero__(self):
        r"""__nonzero__(self) -> bool"""
        return _itkTubeSpatialObjectPython.listitkPointBasedSpatialObjectTube3_Pointer___nonzero__(self)

    def __bool__(self):
        r"""__bool__(self) -> bool"""
        return _itkTubeSpatialObjectPython.listitkPointBasedSpatialObjectTube3_Pointer___bool__(self)

    def __len__(self):
        r"""__len__(self) -> std::list< itkPointBasedSpatialObjectTube3_Pointer >::size_type"""
        return _itkTubeSpatialObjectPython.listitkPointBasedSpatialObjectTube3_Pointer___len__(self)

    def __getslice__(self, i, j):
        r"""
        __getslice__(self, i, j) -> listitkPointBasedSpatialObjectTube3_Pointer

        Parameters
        ----------
        i: std::list< itkPointBasedSpatialObjectTube3_Pointer >::difference_type
        j: std::list< itkPointBasedSpatialObjectTube3_Pointer >::difference_type

        """
        return _itkTubeSpatialObjectPython.listitkPointBasedSpatialObjectTube3_Pointer___getslice__(self, i, j)

    def __setslice__(self, *args):
        r"""
        __setslice__(self, i, j)

        Parameters
        ----------
        i: std::list< itkPointBasedSpatialObjectTube3_Pointer >::difference_type
        j: std::list< itkPointBasedSpatialObjectTube3_Pointer >::difference_type

        __setslice__(self, i, j, v)

        Parameters
        ----------
        i: std::list< itkPointBasedSpatialObjectTube3_Pointer >::difference_type
        j: std::list< itkPointBasedSpatialObjectTube3_Pointer >::difference_type
        v: std::list< itkPointBasedSpatialObjectTube3_Pointer,std::allocator< itkPointBasedSpatialObjectTube3_Pointer > > const &

        """
        return _itkTubeSpatialObjectPython.listitkPointBasedSpatialObjectTube3_Pointer___setslice__(self, *args)

    def __delslice__(self, i, j):
        r"""
        __delslice__(self, i, j)

        Parameters
        ----------
        i: std::list< itkPointBasedSpatialObjectTube3_Pointer >::difference_type
        j: std::list< itkPointBasedSpatialObjectTube3_Pointer >::difference_type

        """
        return _itkTubeSpatialObjectPython.listitkPointBasedSpatialObjectTube3_Pointer___delslice__(self, i, j)

    def __delitem__(self, *args):
        r"""
        __delitem__(self, i)

        Parameters
        ----------
        i: std::list< itkPointBasedSpatialObjectTube3_Pointer >::difference_type

        __delitem__(self, slice)

        Parameters
        ----------
        slice: SWIGPY_SLICEOBJECT *

        """
        return _itkTubeSpatialObjectPython.listitkPointBasedSpatialObjectTube3_Pointer___delitem__(self, *args)

    def __getitem__(self, *args):
        r"""
        __getitem__(self, slice) -> listitkPointBasedSpatialObjectTube3_Pointer

        Parameters
        ----------
        slice: SWIGPY_SLICEOBJECT *

        __getitem__(self, i) -> std::list< itkPointBasedSpatialObjectTube3_Pointer >::value_type const &

        Parameters
        ----------
        i: std::list< itkPointBasedSpatialObjectTube3_Pointer >::difference_type

        """
        return _itkTubeSpatialObjectPython.listitkPointBasedSpatialObjectTube3_Pointer___getitem__(self, *args)

    def __setitem__(self, *args):
        r"""
        __setitem__(self, slice, v)

        Parameters
        ----------
        slice: SWIGPY_SLICEOBJECT *
        v: std::list< itkPointBasedSpatialObjectTube3_Pointer,std::allocator< itkPointBasedSpatialObjectTube3_Pointer > > const &

        __setitem__(self, slice)

        Parameters
        ----------
        slice: SWIGPY_SLICEOBJECT *

        __setitem__(self, i, x)

        Parameters
        ----------
        i: std::list< itkPointBasedSpatialObjectTube3_Pointer >::difference_type
        x: std::list< itkPointBasedSpatialObjectTube3_Pointer >::value_type const &

        """
        return _itkTubeSpatialObjectPython.listitkPointBasedSpatialObjectTube3_Pointer___setitem__(self, *args)

    def pop(self):
        r"""pop(self) -> std::list< itkPointBasedSpatialObjectTube3_Pointer >::value_type"""
        return _itkTubeSpatialObjectPython.listitkPointBasedSpatialObjectTube3_Pointer_pop(self)

    def append(self, x):
        r"""
        append(self, x)

        Parameters
        ----------
        x: std::list< itkPointBasedSpatialObjectTube3_Pointer >::value_type const &

        """
        return _itkTubeSpatialObjectPython.listitkPointBasedSpatialObjectTube3_Pointer_append(self, x)

    def empty(self):
        r"""empty(self) -> bool"""
        return _itkTubeSpatialObjectPython.listitkPointBasedSpatialObjectTube3_Pointer_empty(self)

    def size(self):
        r"""size(self) -> std::list< itkPointBasedSpatialObjectTube3_Pointer >::size_type"""
        return _itkTubeSpatialObjectPython.listitkPointBasedSpatialObjectTube3_Pointer_size(self)

    def swap(self, v):
        r"""
        swap(self, v)

        Parameters
        ----------
        v: std::list< itkPointBasedSpatialObjectTube3_Pointer > &

        """
        return _itkTubeSpatialObjectPython.listitkPointBasedSpatialObjectTube3_Pointer_swap(self, v)

    def begin(self):
        r"""begin(self) -> std::list< itkPointBasedSpatialObjectTube3_Pointer >::iterator"""
        return _itkTubeSpatialObjectPython.listitkPointBasedSpatialObjectTube3_Pointer_begin(self)

    def end(self):
        r"""end(self) -> std::list< itkPointBasedSpatialObjectTube3_Pointer >::iterator"""
        return _itkTubeSpatialObjectPython.listitkPointBasedSpatialObjectTube3_Pointer_end(self)

    def rbegin(self):
        r"""rbegin(self) -> std::list< itkPointBasedSpatialObjectTube3_Pointer >::reverse_iterator"""
        return _itkTubeSpatialObjectPython.listitkPointBasedSpatialObjectTube3_Pointer_rbegin(self)

    def rend(self):
        r"""rend(self) -> std::list< itkPointBasedSpatialObjectTube3_Pointer >::reverse_iterator"""
        return _itkTubeSpatialObjectPython.listitkPointBasedSpatialObjectTube3_Pointer_rend(self)

    def clear(self):
        r"""clear(self)"""
        return _itkTubeSpatialObjectPython.listitkPointBasedSpatialObjectTube3_Pointer_clear(self)

    def get_allocator(self):
        r"""get_allocator(self) -> std::list< itkPointBasedSpatialObjectTube3_Pointer >::allocator_type"""
        return _itkTubeSpatialObjectPython.listitkPointBasedSpatialObjectTube3_Pointer_get_allocator(self)

    def pop_back(self):
        r"""pop_back(self)"""
        return _itkTubeSpatialObjectPython.listitkPointBasedSpatialObjectTube3_Pointer_pop_back(self)

    def erase(self, *args):
        r"""
        erase(self, pos) -> std::list< itkPointBasedSpatialObjectTube3_Pointer >::iterator

        Parameters
        ----------
        pos: std::list< itkPointBasedSpatialObjectTube3_Pointer >::iterator

        erase(self, first, last) -> std::list< itkPointBasedSpatialObjectTube3_Pointer >::iterator

        Parameters
        ----------
        first: std::list< itkPointBasedSpatialObjectTube3_Pointer >::iterator
        last: std::list< itkPointBasedSpatialObjectTube3_Pointer >::iterator

        """
        return _itkTubeSpatialObjectPython.listitkPointBasedSpatialObjectTube3_Pointer_erase(self, *args)

    def __init__(self, *args):
        r"""
        __init__(self) -> listitkPointBasedSpatialObjectTube3_Pointer
        __init__(self, other) -> listitkPointBasedSpatialObjectTube3_Pointer

        Parameters
        ----------
        other: std::list< itkPointBasedSpatialObjectTube3_Pointer > const &

        __init__(self, size) -> listitkPointBasedSpatialObjectTube3_Pointer

        Parameters
        ----------
        size: std::list< itkPointBasedSpatialObjectTube3_Pointer >::size_type

        __init__(self, size, value) -> listitkPointBasedSpatialObjectTube3_Pointer

        Parameters
        ----------
        size: std::list< itkPointBasedSpatialObjectTube3_Pointer >::size_type
        value: std::list< itkPointBasedSpatialObjectTube3_Pointer >::value_type const &

        """
        _itkTubeSpatialObjectPython.listitkPointBasedSpatialObjectTube3_Pointer_swiginit(self, _itkTubeSpatialObjectPython.new_listitkPointBasedSpatialObjectTube3_Pointer(*args))

    def push_back(self, x):
        r"""
        push_back(self, x)

        Parameters
        ----------
        x: std::list< itkPointBasedSpatialObjectTube3_Pointer >::value_type const &

        """
        return _itkTubeSpatialObjectPython.listitkPointBasedSpatialObjectTube3_Pointer_push_back(self, x)

    def front(self):
        r"""front(self) -> std::list< itkPointBasedSpatialObjectTube3_Pointer >::value_type const &"""
        return _itkTubeSpatialObjectPython.listitkPointBasedSpatialObjectTube3_Pointer_front(self)

    def back(self):
        r"""back(self) -> std::list< itkPointBasedSpatialObjectTube3_Pointer >::value_type const &"""
        return _itkTubeSpatialObjectPython.listitkPointBasedSpatialObjectTube3_Pointer_back(self)

    def assign(self, n, x):
        r"""
        assign(self, n, x)

        Parameters
        ----------
        n: std::list< itkPointBasedSpatialObjectTube3_Pointer >::size_type
        x: std::list< itkPointBasedSpatialObjectTube3_Pointer >::value_type const &

        """
        return _itkTubeSpatialObjectPython.listitkPointBasedSpatialObjectTube3_Pointer_assign(self, n, x)

    def resize(self, *args):
        r"""
        resize(self, new_size)

        Parameters
        ----------
        new_size: std::list< itkPointBasedSpatialObjectTube3_Pointer >::size_type

        resize(self, new_size, x)

        Parameters
        ----------
        new_size: std::list< itkPointBasedSpatialObjectTube3_Pointer >::size_type
        x: std::list< itkPointBasedSpatialObjectTube3_Pointer >::value_type const &

        """
        return _itkTubeSpatialObjectPython.listitkPointBasedSpatialObjectTube3_Pointer_resize(self, *args)

    def insert(self, *args):
        r"""
        insert(self, pos, x) -> std::list< itkPointBasedSpatialObjectTube3_Pointer >::iterator

        Parameters
        ----------
        pos: std::list< itkPointBasedSpatialObjectTube3_Pointer >::iterator
        x: std::list< itkPointBasedSpatialObjectTube3_Pointer >::value_type const &

        insert(self, pos, n, x)

        Parameters
        ----------
        pos: std::list< itkPointBasedSpatialObjectTube3_Pointer >::iterator
        n: std::list< itkPointBasedSpatialObjectTube3_Pointer >::size_type
        x: std::list< itkPointBasedSpatialObjectTube3_Pointer >::value_type const &

        """
        return _itkTubeSpatialObjectPython.listitkPointBasedSpatialObjectTube3_Pointer_insert(self, *args)

    def pop_front(self):
        r"""pop_front(self)"""
        return _itkTubeSpatialObjectPython.listitkPointBasedSpatialObjectTube3_Pointer_pop_front(self)

    def push_front(self, x):
        r"""
        push_front(self, x)

        Parameters
        ----------
        x: std::list< itkPointBasedSpatialObjectTube3_Pointer >::value_type const &

        """
        return _itkTubeSpatialObjectPython.listitkPointBasedSpatialObjectTube3_Pointer_push_front(self, x)

    def reverse(self):
        r"""reverse(self)"""
        return _itkTubeSpatialObjectPython.listitkPointBasedSpatialObjectTube3_Pointer_reverse(self)
    __swig_destroy__ = _itkTubeSpatialObjectPython.delete_listitkPointBasedSpatialObjectTube3_Pointer

# Register listitkPointBasedSpatialObjectTube3_Pointer in _itkTubeSpatialObjectPython:
_itkTubeSpatialObjectPython.listitkPointBasedSpatialObjectTube3_Pointer_swigregister(listitkPointBasedSpatialObjectTube3_Pointer)
class listitkTubeSpatialObject2_Pointer(collections.abc.MutableSequence if _swig_python_version_info >= (3, 3) else collections.MutableSequence):
    r"""Proxy of C++ std::list< itkTubeSpatialObject2_Pointer > class."""

    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def iterator(self):
        r"""iterator(self) -> SwigPyIterator"""
        return _itkTubeSpatialObjectPython.listitkTubeSpatialObject2_Pointer_iterator(self)
    def __iter__(self):
        return self.iterator()

    def __nonzero__(self):
        r"""__nonzero__(self) -> bool"""
        return _itkTubeSpatialObjectPython.listitkTubeSpatialObject2_Pointer___nonzero__(self)

    def __bool__(self):
        r"""__bool__(self) -> bool"""
        return _itkTubeSpatialObjectPython.listitkTubeSpatialObject2_Pointer___bool__(self)

    def __len__(self):
        r"""__len__(self) -> std::list< itkTubeSpatialObject2_Pointer >::size_type"""
        return _itkTubeSpatialObjectPython.listitkTubeSpatialObject2_Pointer___len__(self)

    def __getslice__(self, i, j):
        r"""
        __getslice__(self, i, j) -> listitkTubeSpatialObject2_Pointer

        Parameters
        ----------
        i: std::list< itkTubeSpatialObject2_Pointer >::difference_type
        j: std::list< itkTubeSpatialObject2_Pointer >::difference_type

        """
        return _itkTubeSpatialObjectPython.listitkTubeSpatialObject2_Pointer___getslice__(self, i, j)

    def __setslice__(self, *args):
        r"""
        __setslice__(self, i, j)

        Parameters
        ----------
        i: std::list< itkTubeSpatialObject2_Pointer >::difference_type
        j: std::list< itkTubeSpatialObject2_Pointer >::difference_type

        __setslice__(self, i, j, v)

        Parameters
        ----------
        i: std::list< itkTubeSpatialObject2_Pointer >::difference_type
        j: std::list< itkTubeSpatialObject2_Pointer >::difference_type
        v: std::list< itkTubeSpatialObject2_Pointer,std::allocator< itkTubeSpatialObject2_Pointer > > const &

        """
        return _itkTubeSpatialObjectPython.listitkTubeSpatialObject2_Pointer___setslice__(self, *args)

    def __delslice__(self, i, j):
        r"""
        __delslice__(self, i, j)

        Parameters
        ----------
        i: std::list< itkTubeSpatialObject2_Pointer >::difference_type
        j: std::list< itkTubeSpatialObject2_Pointer >::difference_type

        """
        return _itkTubeSpatialObjectPython.listitkTubeSpatialObject2_Pointer___delslice__(self, i, j)

    def __delitem__(self, *args):
        r"""
        __delitem__(self, i)

        Parameters
        ----------
        i: std::list< itkTubeSpatialObject2_Pointer >::difference_type

        __delitem__(self, slice)

        Parameters
        ----------
        slice: SWIGPY_SLICEOBJECT *

        """
        return _itkTubeSpatialObjectPython.listitkTubeSpatialObject2_Pointer___delitem__(self, *args)

    def __getitem__(self, *args):
        r"""
        __getitem__(self, slice) -> listitkTubeSpatialObject2_Pointer

        Parameters
        ----------
        slice: SWIGPY_SLICEOBJECT *

        __getitem__(self, i) -> std::list< itkTubeSpatialObject2_Pointer >::value_type const &

        Parameters
        ----------
        i: std::list< itkTubeSpatialObject2_Pointer >::difference_type

        """
        return _itkTubeSpatialObjectPython.listitkTubeSpatialObject2_Pointer___getitem__(self, *args)

    def __setitem__(self, *args):
        r"""
        __setitem__(self, slice, v)

        Parameters
        ----------
        slice: SWIGPY_SLICEOBJECT *
        v: std::list< itkTubeSpatialObject2_Pointer,std::allocator< itkTubeSpatialObject2_Pointer > > const &

        __setitem__(self, slice)

        Parameters
        ----------
        slice: SWIGPY_SLICEOBJECT *

        __setitem__(self, i, x)

        Parameters
        ----------
        i: std::list< itkTubeSpatialObject2_Pointer >::difference_type
        x: std::list< itkTubeSpatialObject2_Pointer >::value_type const &

        """
        return _itkTubeSpatialObjectPython.listitkTubeSpatialObject2_Pointer___setitem__(self, *args)

    def pop(self):
        r"""pop(self) -> std::list< itkTubeSpatialObject2_Pointer >::value_type"""
        return _itkTubeSpatialObjectPython.listitkTubeSpatialObject2_Pointer_pop(self)

    def append(self, x):
        r"""
        append(self, x)

        Parameters
        ----------
        x: std::list< itkTubeSpatialObject2_Pointer >::value_type const &

        """
        return _itkTubeSpatialObjectPython.listitkTubeSpatialObject2_Pointer_append(self, x)

    def empty(self):
        r"""empty(self) -> bool"""
        return _itkTubeSpatialObjectPython.listitkTubeSpatialObject2_Pointer_empty(self)

    def size(self):
        r"""size(self) -> std::list< itkTubeSpatialObject2_Pointer >::size_type"""
        return _itkTubeSpatialObjectPython.listitkTubeSpatialObject2_Pointer_size(self)

    def swap(self, v):
        r"""
        swap(self, v)

        Parameters
        ----------
        v: std::list< itkTubeSpatialObject2_Pointer > &

        """
        return _itkTubeSpatialObjectPython.listitkTubeSpatialObject2_Pointer_swap(self, v)

    def begin(self):
        r"""begin(self) -> std::list< itkTubeSpatialObject2_Pointer >::iterator"""
        return _itkTubeSpatialObjectPython.listitkTubeSpatialObject2_Pointer_begin(self)

    def end(self):
        r"""end(self) -> std::list< itkTubeSpatialObject2_Pointer >::iterator"""
        return _itkTubeSpatialObjectPython.listitkTubeSpatialObject2_Pointer_end(self)

    def rbegin(self):
        r"""rbegin(self) -> std::list< itkTubeSpatialObject2_Pointer >::reverse_iterator"""
        return _itkTubeSpatialObjectPython.listitkTubeSpatialObject2_Pointer_rbegin(self)

    def rend(self):
        r"""rend(self) -> std::list< itkTubeSpatialObject2_Pointer >::reverse_iterator"""
        return _itkTubeSpatialObjectPython.listitkTubeSpatialObject2_Pointer_rend(self)

    def clear(self):
        r"""clear(self)"""
        return _itkTubeSpatialObjectPython.listitkTubeSpatialObject2_Pointer_clear(self)

    def get_allocator(self):
        r"""get_allocator(self) -> std::list< itkTubeSpatialObject2_Pointer >::allocator_type"""
        return _itkTubeSpatialObjectPython.listitkTubeSpatialObject2_Pointer_get_allocator(self)

    def pop_back(self):
        r"""pop_back(self)"""
        return _itkTubeSpatialObjectPython.listitkTubeSpatialObject2_Pointer_pop_back(self)

    def erase(self, *args):
        r"""
        erase(self, pos) -> std::list< itkTubeSpatialObject2_Pointer >::iterator

        Parameters
        ----------
        pos: std::list< itkTubeSpatialObject2_Pointer >::iterator

        erase(self, first, last) -> std::list< itkTubeSpatialObject2_Pointer >::iterator

        Parameters
        ----------
        first: std::list< itkTubeSpatialObject2_Pointer >::iterator
        last: std::list< itkTubeSpatialObject2_Pointer >::iterator

        """
        return _itkTubeSpatialObjectPython.listitkTubeSpatialObject2_Pointer_erase(self, *args)

    def __init__(self, *args):
        r"""
        __init__(self) -> listitkTubeSpatialObject2_Pointer
        __init__(self, other) -> listitkTubeSpatialObject2_Pointer

        Parameters
        ----------
        other: std::list< itkTubeSpatialObject2_Pointer > const &

        __init__(self, size) -> listitkTubeSpatialObject2_Pointer

        Parameters
        ----------
        size: std::list< itkTubeSpatialObject2_Pointer >::size_type

        __init__(self, size, value) -> listitkTubeSpatialObject2_Pointer

        Parameters
        ----------
        size: std::list< itkTubeSpatialObject2_Pointer >::size_type
        value: std::list< itkTubeSpatialObject2_Pointer >::value_type const &

        """
        _itkTubeSpatialObjectPython.listitkTubeSpatialObject2_Pointer_swiginit(self, _itkTubeSpatialObjectPython.new_listitkTubeSpatialObject2_Pointer(*args))

    def push_back(self, x):
        r"""
        push_back(self, x)

        Parameters
        ----------
        x: std::list< itkTubeSpatialObject2_Pointer >::value_type const &

        """
        return _itkTubeSpatialObjectPython.listitkTubeSpatialObject2_Pointer_push_back(self, x)

    def front(self):
        r"""front(self) -> std::list< itkTubeSpatialObject2_Pointer >::value_type const &"""
        return _itkTubeSpatialObjectPython.listitkTubeSpatialObject2_Pointer_front(self)

    def back(self):
        r"""back(self) -> std::list< itkTubeSpatialObject2_Pointer >::value_type const &"""
        return _itkTubeSpatialObjectPython.listitkTubeSpatialObject2_Pointer_back(self)

    def assign(self, n, x):
        r"""
        assign(self, n, x)

        Parameters
        ----------
        n: std::list< itkTubeSpatialObject2_Pointer >::size_type
        x: std::list< itkTubeSpatialObject2_Pointer >::value_type const &

        """
        return _itkTubeSpatialObjectPython.listitkTubeSpatialObject2_Pointer_assign(self, n, x)

    def resize(self, *args):
        r"""
        resize(self, new_size)

        Parameters
        ----------
        new_size: std::list< itkTubeSpatialObject2_Pointer >::size_type

        resize(self, new_size, x)

        Parameters
        ----------
        new_size: std::list< itkTubeSpatialObject2_Pointer >::size_type
        x: std::list< itkTubeSpatialObject2_Pointer >::value_type const &

        """
        return _itkTubeSpatialObjectPython.listitkTubeSpatialObject2_Pointer_resize(self, *args)

    def insert(self, *args):
        r"""
        insert(self, pos, x) -> std::list< itkTubeSpatialObject2_Pointer >::iterator

        Parameters
        ----------
        pos: std::list< itkTubeSpatialObject2_Pointer >::iterator
        x: std::list< itkTubeSpatialObject2_Pointer >::value_type const &

        insert(self, pos, n, x)

        Parameters
        ----------
        pos: std::list< itkTubeSpatialObject2_Pointer >::iterator
        n: std::list< itkTubeSpatialObject2_Pointer >::size_type
        x: std::list< itkTubeSpatialObject2_Pointer >::value_type const &

        """
        return _itkTubeSpatialObjectPython.listitkTubeSpatialObject2_Pointer_insert(self, *args)

    def pop_front(self):
        r"""pop_front(self)"""
        return _itkTubeSpatialObjectPython.listitkTubeSpatialObject2_Pointer_pop_front(self)

    def push_front(self, x):
        r"""
        push_front(self, x)

        Parameters
        ----------
        x: std::list< itkTubeSpatialObject2_Pointer >::value_type const &

        """
        return _itkTubeSpatialObjectPython.listitkTubeSpatialObject2_Pointer_push_front(self, x)

    def reverse(self):
        r"""reverse(self)"""
        return _itkTubeSpatialObjectPython.listitkTubeSpatialObject2_Pointer_reverse(self)
    __swig_destroy__ = _itkTubeSpatialObjectPython.delete_listitkTubeSpatialObject2_Pointer

# Register listitkTubeSpatialObject2_Pointer in _itkTubeSpatialObjectPython:
_itkTubeSpatialObjectPython.listitkTubeSpatialObject2_Pointer_swigregister(listitkTubeSpatialObject2_Pointer)
class listitkTubeSpatialObject3_Pointer(collections.abc.MutableSequence if _swig_python_version_info >= (3, 3) else collections.MutableSequence):
    r"""Proxy of C++ std::list< itkTubeSpatialObject3_Pointer > class."""

    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def iterator(self):
        r"""iterator(self) -> SwigPyIterator"""
        return _itkTubeSpatialObjectPython.listitkTubeSpatialObject3_Pointer_iterator(self)
    def __iter__(self):
        return self.iterator()

    def __nonzero__(self):
        r"""__nonzero__(self) -> bool"""
        return _itkTubeSpatialObjectPython.listitkTubeSpatialObject3_Pointer___nonzero__(self)

    def __bool__(self):
        r"""__bool__(self) -> bool"""
        return _itkTubeSpatialObjectPython.listitkTubeSpatialObject3_Pointer___bool__(self)

    def __len__(self):
        r"""__len__(self) -> std::list< itkTubeSpatialObject3_Pointer >::size_type"""
        return _itkTubeSpatialObjectPython.listitkTubeSpatialObject3_Pointer___len__(self)

    def __getslice__(self, i, j):
        r"""
        __getslice__(self, i, j) -> listitkTubeSpatialObject3_Pointer

        Parameters
        ----------
        i: std::list< itkTubeSpatialObject3_Pointer >::difference_type
        j: std::list< itkTubeSpatialObject3_Pointer >::difference_type

        """
        return _itkTubeSpatialObjectPython.listitkTubeSpatialObject3_Pointer___getslice__(self, i, j)

    def __setslice__(self, *args):
        r"""
        __setslice__(self, i, j)

        Parameters
        ----------
        i: std::list< itkTubeSpatialObject3_Pointer >::difference_type
        j: std::list< itkTubeSpatialObject3_Pointer >::difference_type

        __setslice__(self, i, j, v)

        Parameters
        ----------
        i: std::list< itkTubeSpatialObject3_Pointer >::difference_type
        j: std::list< itkTubeSpatialObject3_Pointer >::difference_type
        v: std::list< itkTubeSpatialObject3_Pointer,std::allocator< itkTubeSpatialObject3_Pointer > > const &

        """
        return _itkTubeSpatialObjectPython.listitkTubeSpatialObject3_Pointer___setslice__(self, *args)

    def __delslice__(self, i, j):
        r"""
        __delslice__(self, i, j)

        Parameters
        ----------
        i: std::list< itkTubeSpatialObject3_Pointer >::difference_type
        j: std::list< itkTubeSpatialObject3_Pointer >::difference_type

        """
        return _itkTubeSpatialObjectPython.listitkTubeSpatialObject3_Pointer___delslice__(self, i, j)

    def __delitem__(self, *args):
        r"""
        __delitem__(self, i)

        Parameters
        ----------
        i: std::list< itkTubeSpatialObject3_Pointer >::difference_type

        __delitem__(self, slice)

        Parameters
        ----------
        slice: SWIGPY_SLICEOBJECT *

        """
        return _itkTubeSpatialObjectPython.listitkTubeSpatialObject3_Pointer___delitem__(self, *args)

    def __getitem__(self, *args):
        r"""
        __getitem__(self, slice) -> listitkTubeSpatialObject3_Pointer

        Parameters
        ----------
        slice: SWIGPY_SLICEOBJECT *

        __getitem__(self, i) -> std::list< itkTubeSpatialObject3_Pointer >::value_type const &

        Parameters
        ----------
        i: std::list< itkTubeSpatialObject3_Pointer >::difference_type

        """
        return _itkTubeSpatialObjectPython.listitkTubeSpatialObject3_Pointer___getitem__(self, *args)

    def __setitem__(self, *args):
        r"""
        __setitem__(self, slice, v)

        Parameters
        ----------
        slice: SWIGPY_SLICEOBJECT *
        v: std::list< itkTubeSpatialObject3_Pointer,std::allocator< itkTubeSpatialObject3_Pointer > > const &

        __setitem__(self, slice)

        Parameters
        ----------
        slice: SWIGPY_SLICEOBJECT *

        __setitem__(self, i, x)

        Parameters
        ----------
        i: std::list< itkTubeSpatialObject3_Pointer >::difference_type
        x: std::list< itkTubeSpatialObject3_Pointer >::value_type const &

        """
        return _itkTubeSpatialObjectPython.listitkTubeSpatialObject3_Pointer___setitem__(self, *args)

    def pop(self):
        r"""pop(self) -> std::list< itkTubeSpatialObject3_Pointer >::value_type"""
        return _itkTubeSpatialObjectPython.listitkTubeSpatialObject3_Pointer_pop(self)

    def append(self, x):
        r"""
        append(self, x)

        Parameters
        ----------
        x: std::list< itkTubeSpatialObject3_Pointer >::value_type const &

        """
        return _itkTubeSpatialObjectPython.listitkTubeSpatialObject3_Pointer_append(self, x)

    def empty(self):
        r"""empty(self) -> bool"""
        return _itkTubeSpatialObjectPython.listitkTubeSpatialObject3_Pointer_empty(self)

    def size(self):
        r"""size(self) -> std::list< itkTubeSpatialObject3_Pointer >::size_type"""
        return _itkTubeSpatialObjectPython.listitkTubeSpatialObject3_Pointer_size(self)

    def swap(self, v):
        r"""
        swap(self, v)

        Parameters
        ----------
        v: std::list< itkTubeSpatialObject3_Pointer > &

        """
        return _itkTubeSpatialObjectPython.listitkTubeSpatialObject3_Pointer_swap(self, v)

    def begin(self):
        r"""begin(self) -> std::list< itkTubeSpatialObject3_Pointer >::iterator"""
        return _itkTubeSpatialObjectPython.listitkTubeSpatialObject3_Pointer_begin(self)

    def end(self):
        r"""end(self) -> std::list< itkTubeSpatialObject3_Pointer >::iterator"""
        return _itkTubeSpatialObjectPython.listitkTubeSpatialObject3_Pointer_end(self)

    def rbegin(self):
        r"""rbegin(self) -> std::list< itkTubeSpatialObject3_Pointer >::reverse_iterator"""
        return _itkTubeSpatialObjectPython.listitkTubeSpatialObject3_Pointer_rbegin(self)

    def rend(self):
        r"""rend(self) -> std::list< itkTubeSpatialObject3_Pointer >::reverse_iterator"""
        return _itkTubeSpatialObjectPython.listitkTubeSpatialObject3_Pointer_rend(self)

    def clear(self):
        r"""clear(self)"""
        return _itkTubeSpatialObjectPython.listitkTubeSpatialObject3_Pointer_clear(self)

    def get_allocator(self):
        r"""get_allocator(self) -> std::list< itkTubeSpatialObject3_Pointer >::allocator_type"""
        return _itkTubeSpatialObjectPython.listitkTubeSpatialObject3_Pointer_get_allocator(self)

    def pop_back(self):
        r"""pop_back(self)"""
        return _itkTubeSpatialObjectPython.listitkTubeSpatialObject3_Pointer_pop_back(self)

    def erase(self, *args):
        r"""
        erase(self, pos) -> std::list< itkTubeSpatialObject3_Pointer >::iterator

        Parameters
        ----------
        pos: std::list< itkTubeSpatialObject3_Pointer >::iterator

        erase(self, first, last) -> std::list< itkTubeSpatialObject3_Pointer >::iterator

        Parameters
        ----------
        first: std::list< itkTubeSpatialObject3_Pointer >::iterator
        last: std::list< itkTubeSpatialObject3_Pointer >::iterator

        """
        return _itkTubeSpatialObjectPython.listitkTubeSpatialObject3_Pointer_erase(self, *args)

    def __init__(self, *args):
        r"""
        __init__(self) -> listitkTubeSpatialObject3_Pointer
        __init__(self, other) -> listitkTubeSpatialObject3_Pointer

        Parameters
        ----------
        other: std::list< itkTubeSpatialObject3_Pointer > const &

        __init__(self, size) -> listitkTubeSpatialObject3_Pointer

        Parameters
        ----------
        size: std::list< itkTubeSpatialObject3_Pointer >::size_type

        __init__(self, size, value) -> listitkTubeSpatialObject3_Pointer

        Parameters
        ----------
        size: std::list< itkTubeSpatialObject3_Pointer >::size_type
        value: std::list< itkTubeSpatialObject3_Pointer >::value_type const &

        """
        _itkTubeSpatialObjectPython.listitkTubeSpatialObject3_Pointer_swiginit(self, _itkTubeSpatialObjectPython.new_listitkTubeSpatialObject3_Pointer(*args))

    def push_back(self, x):
        r"""
        push_back(self, x)

        Parameters
        ----------
        x: std::list< itkTubeSpatialObject3_Pointer >::value_type const &

        """
        return _itkTubeSpatialObjectPython.listitkTubeSpatialObject3_Pointer_push_back(self, x)

    def front(self):
        r"""front(self) -> std::list< itkTubeSpatialObject3_Pointer >::value_type const &"""
        return _itkTubeSpatialObjectPython.listitkTubeSpatialObject3_Pointer_front(self)

    def back(self):
        r"""back(self) -> std::list< itkTubeSpatialObject3_Pointer >::value_type const &"""
        return _itkTubeSpatialObjectPython.listitkTubeSpatialObject3_Pointer_back(self)

    def assign(self, n, x):
        r"""
        assign(self, n, x)

        Parameters
        ----------
        n: std::list< itkTubeSpatialObject3_Pointer >::size_type
        x: std::list< itkTubeSpatialObject3_Pointer >::value_type const &

        """
        return _itkTubeSpatialObjectPython.listitkTubeSpatialObject3_Pointer_assign(self, n, x)

    def resize(self, *args):
        r"""
        resize(self, new_size)

        Parameters
        ----------
        new_size: std::list< itkTubeSpatialObject3_Pointer >::size_type

        resize(self, new_size, x)

        Parameters
        ----------
        new_size: std::list< itkTubeSpatialObject3_Pointer >::size_type
        x: std::list< itkTubeSpatialObject3_Pointer >::value_type const &

        """
        return _itkTubeSpatialObjectPython.listitkTubeSpatialObject3_Pointer_resize(self, *args)

    def insert(self, *args):
        r"""
        insert(self, pos, x) -> std::list< itkTubeSpatialObject3_Pointer >::iterator

        Parameters
        ----------
        pos: std::list< itkTubeSpatialObject3_Pointer >::iterator
        x: std::list< itkTubeSpatialObject3_Pointer >::value_type const &

        insert(self, pos, n, x)

        Parameters
        ----------
        pos: std::list< itkTubeSpatialObject3_Pointer >::iterator
        n: std::list< itkTubeSpatialObject3_Pointer >::size_type
        x: std::list< itkTubeSpatialObject3_Pointer >::value_type const &

        """
        return _itkTubeSpatialObjectPython.listitkTubeSpatialObject3_Pointer_insert(self, *args)

    def pop_front(self):
        r"""pop_front(self)"""
        return _itkTubeSpatialObjectPython.listitkTubeSpatialObject3_Pointer_pop_front(self)

    def push_front(self, x):
        r"""
        push_front(self, x)

        Parameters
        ----------
        x: std::list< itkTubeSpatialObject3_Pointer >::value_type const &

        """
        return _itkTubeSpatialObjectPython.listitkTubeSpatialObject3_Pointer_push_front(self, x)

    def reverse(self):
        r"""reverse(self)"""
        return _itkTubeSpatialObjectPython.listitkTubeSpatialObject3_Pointer_reverse(self)
    __swig_destroy__ = _itkTubeSpatialObjectPython.delete_listitkTubeSpatialObject3_Pointer

# Register listitkTubeSpatialObject3_Pointer in _itkTubeSpatialObjectPython:
_itkTubeSpatialObjectPython.listitkTubeSpatialObject3_Pointer_swigregister(listitkTubeSpatialObject3_Pointer)

def itkPointBasedSpatialObjectTube2_New():
    return itkPointBasedSpatialObjectTube2.New()

class itkPointBasedSpatialObjectTube2(itk.itkSpatialObjectBasePython.itkSpatialObject2):
    r"""Proxy of C++ itkPointBasedSpatialObjectTube2 class."""

    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")

    def __init__(self, *args, **kwargs):
        raise AttributeError("No constructor defined")
    __repr__ = _swig_repr

    @staticmethod
    def __New_orig__():
        r"""__New_orig__() -> itkPointBasedSpatialObjectTube2_Pointer"""
        return _itkTubeSpatialObjectPython.itkPointBasedSpatialObjectTube2___New_orig__()

    def Clone(self):
        r"""Clone(self) -> itkPointBasedSpatialObjectTube2_Pointer"""
        return _itkTubeSpatialObjectPython.itkPointBasedSpatialObjectTube2_Clone(self)

    def AddPoint(self, newPoint):
        r"""
        AddPoint(self, newPoint)

        Parameters
        ----------
        newPoint: itkTubeSpatialObjectPoint2 const &

        """
        return _itkTubeSpatialObjectPython.itkPointBasedSpatialObjectTube2_AddPoint(self, newPoint)

    def RemovePoint(self, id):
        r"""
        RemovePoint(self, id)

        Parameters
        ----------
        id: unsigned long

        """
        return _itkTubeSpatialObjectPython.itkPointBasedSpatialObjectTube2_RemovePoint(self, id)

    def SetPoints(self, newPoints):
        r"""
        SetPoints(self, newPoints)

        Parameters
        ----------
        newPoints: std::vector< itkTubeSpatialObjectPoint2,std::allocator< itkTubeSpatialObjectPoint2 > > const &

        """
        return _itkTubeSpatialObjectPython.itkPointBasedSpatialObjectTube2_SetPoints(self, newPoints)

    def GetPoints(self, *args):
        r"""
        GetPoints(self) -> vectoritkTubeSpatialObjectPoint2
        GetPoints(self) -> vectoritkTubeSpatialObjectPoint2
        """
        return _itkTubeSpatialObjectPython.itkPointBasedSpatialObjectTube2_GetPoints(self, *args)

    def GetPoint(self, *args):
        r"""
        GetPoint(self, id) -> itkTubeSpatialObjectPoint2

        Parameters
        ----------
        id: unsigned long

        GetPoint(self, id) -> itkTubeSpatialObjectPoint2

        Parameters
        ----------
        id: unsigned long

        """
        return _itkTubeSpatialObjectPython.itkPointBasedSpatialObjectTube2_GetPoint(self, *args)

    def GetNumberOfPoints(self):
        r"""GetNumberOfPoints(self) -> unsigned long"""
        return _itkTubeSpatialObjectPython.itkPointBasedSpatialObjectTube2_GetNumberOfPoints(self)

    def ClosestPointInWorldSpace(self, point):
        r"""
        ClosestPointInWorldSpace(self, point) -> itkTubeSpatialObjectPoint2

        Parameters
        ----------
        point: itkPointD2 const &

        """
        return _itkTubeSpatialObjectPython.itkPointBasedSpatialObjectTube2_ClosestPointInWorldSpace(self, point)

    def ClosestPointInObjectSpace(self, point):
        r"""
        ClosestPointInObjectSpace(self, point) -> itkTubeSpatialObjectPoint2

        Parameters
        ----------
        point: itkPointD2 const &

        """
        return _itkTubeSpatialObjectPython.itkPointBasedSpatialObjectTube2_ClosestPointInObjectSpace(self, point)
    __swig_destroy__ = _itkTubeSpatialObjectPython.delete_itkPointBasedSpatialObjectTube2

    @staticmethod
    def cast(obj):
        r"""
        cast(obj) -> itkPointBasedSpatialObjectTube2

        Parameters
        ----------
        obj: itkLightObject *

        """
        return _itkTubeSpatialObjectPython.itkPointBasedSpatialObjectTube2_cast(obj)

    def New(*args, **kargs):
        """New() -> itkPointBasedSpatialObjectTube2

        Create a new object of the class itkPointBasedSpatialObjectTube2 and set the input and the parameters if some
        named or non-named arguments are passed to that method.

        New() tries to assign all the non named parameters to the input of the new objects - the
        first non named parameter in the first input, etc.

        The named parameters are used by calling the method with the same name prefixed by 'Set'.

        Ex:

          itkPointBasedSpatialObjectTube2.New(reader, threshold=10)

        is (most of the time) equivalent to:

          obj = itkPointBasedSpatialObjectTube2.New()
          obj.SetInput(0, reader.GetOutput())
          obj.SetThreshold(10)
        """
        obj = itkPointBasedSpatialObjectTube2.__New_orig__()
        from itk.support import template_class
        template_class.New(obj, *args, **kargs)
        return obj
    New = staticmethod(New)


# Register itkPointBasedSpatialObjectTube2 in _itkTubeSpatialObjectPython:
_itkTubeSpatialObjectPython.itkPointBasedSpatialObjectTube2_swigregister(itkPointBasedSpatialObjectTube2)

def itkPointBasedSpatialObjectTube3_New():
    return itkPointBasedSpatialObjectTube3.New()

class itkPointBasedSpatialObjectTube3(itk.itkSpatialObjectBasePython.itkSpatialObject3):
    r"""Proxy of C++ itkPointBasedSpatialObjectTube3 class."""

    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")

    def __init__(self, *args, **kwargs):
        raise AttributeError("No constructor defined")
    __repr__ = _swig_repr

    @staticmethod
    def __New_orig__():
        r"""__New_orig__() -> itkPointBasedSpatialObjectTube3_Pointer"""
        return _itkTubeSpatialObjectPython.itkPointBasedSpatialObjectTube3___New_orig__()

    def Clone(self):
        r"""Clone(self) -> itkPointBasedSpatialObjectTube3_Pointer"""
        return _itkTubeSpatialObjectPython.itkPointBasedSpatialObjectTube3_Clone(self)

    def AddPoint(self, newPoint):
        r"""
        AddPoint(self, newPoint)

        Parameters
        ----------
        newPoint: itkTubeSpatialObjectPoint3 const &

        """
        return _itkTubeSpatialObjectPython.itkPointBasedSpatialObjectTube3_AddPoint(self, newPoint)

    def RemovePoint(self, id):
        r"""
        RemovePoint(self, id)

        Parameters
        ----------
        id: unsigned long

        """
        return _itkTubeSpatialObjectPython.itkPointBasedSpatialObjectTube3_RemovePoint(self, id)

    def SetPoints(self, newPoints):
        r"""
        SetPoints(self, newPoints)

        Parameters
        ----------
        newPoints: std::vector< itkTubeSpatialObjectPoint3,std::allocator< itkTubeSpatialObjectPoint3 > > const &

        """
        return _itkTubeSpatialObjectPython.itkPointBasedSpatialObjectTube3_SetPoints(self, newPoints)

    def GetPoints(self, *args):
        r"""
        GetPoints(self) -> vectoritkTubeSpatialObjectPoint3
        GetPoints(self) -> vectoritkTubeSpatialObjectPoint3
        """
        return _itkTubeSpatialObjectPython.itkPointBasedSpatialObjectTube3_GetPoints(self, *args)

    def GetPoint(self, *args):
        r"""
        GetPoint(self, id) -> itkTubeSpatialObjectPoint3

        Parameters
        ----------
        id: unsigned long

        GetPoint(self, id) -> itkTubeSpatialObjectPoint3

        Parameters
        ----------
        id: unsigned long

        """
        return _itkTubeSpatialObjectPython.itkPointBasedSpatialObjectTube3_GetPoint(self, *args)

    def GetNumberOfPoints(self):
        r"""GetNumberOfPoints(self) -> unsigned long"""
        return _itkTubeSpatialObjectPython.itkPointBasedSpatialObjectTube3_GetNumberOfPoints(self)

    def ClosestPointInWorldSpace(self, point):
        r"""
        ClosestPointInWorldSpace(self, point) -> itkTubeSpatialObjectPoint3

        Parameters
        ----------
        point: itkPointD3 const &

        """
        return _itkTubeSpatialObjectPython.itkPointBasedSpatialObjectTube3_ClosestPointInWorldSpace(self, point)

    def ClosestPointInObjectSpace(self, point):
        r"""
        ClosestPointInObjectSpace(self, point) -> itkTubeSpatialObjectPoint3

        Parameters
        ----------
        point: itkPointD3 const &

        """
        return _itkTubeSpatialObjectPython.itkPointBasedSpatialObjectTube3_ClosestPointInObjectSpace(self, point)
    __swig_destroy__ = _itkTubeSpatialObjectPython.delete_itkPointBasedSpatialObjectTube3

    @staticmethod
    def cast(obj):
        r"""
        cast(obj) -> itkPointBasedSpatialObjectTube3

        Parameters
        ----------
        obj: itkLightObject *

        """
        return _itkTubeSpatialObjectPython.itkPointBasedSpatialObjectTube3_cast(obj)

    def New(*args, **kargs):
        """New() -> itkPointBasedSpatialObjectTube3

        Create a new object of the class itkPointBasedSpatialObjectTube3 and set the input and the parameters if some
        named or non-named arguments are passed to that method.

        New() tries to assign all the non named parameters to the input of the new objects - the
        first non named parameter in the first input, etc.

        The named parameters are used by calling the method with the same name prefixed by 'Set'.

        Ex:

          itkPointBasedSpatialObjectTube3.New(reader, threshold=10)

        is (most of the time) equivalent to:

          obj = itkPointBasedSpatialObjectTube3.New()
          obj.SetInput(0, reader.GetOutput())
          obj.SetThreshold(10)
        """
        obj = itkPointBasedSpatialObjectTube3.__New_orig__()
        from itk.support import template_class
        template_class.New(obj, *args, **kargs)
        return obj
    New = staticmethod(New)


# Register itkPointBasedSpatialObjectTube3 in _itkTubeSpatialObjectPython:
_itkTubeSpatialObjectPython.itkPointBasedSpatialObjectTube3_swigregister(itkPointBasedSpatialObjectTube3)

def itkTubeSpatialObject2_New():
    return itkTubeSpatialObject2.New()

class itkTubeSpatialObject2(itkPointBasedSpatialObjectTube2):
    r"""Proxy of C++ itkTubeSpatialObject2 class."""

    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")

    def __init__(self, *args, **kwargs):
        raise AttributeError("No constructor defined")
    __repr__ = _swig_repr

    @staticmethod
    def __New_orig__():
        r"""__New_orig__() -> itkTubeSpatialObject2_Pointer"""
        return _itkTubeSpatialObjectPython.itkTubeSpatialObject2___New_orig__()

    def Clone(self):
        r"""Clone(self) -> itkTubeSpatialObject2_Pointer"""
        return _itkTubeSpatialObjectPython.itkTubeSpatialObject2_Clone(self)

    def SetEndRounded(self, _arg):
        r"""
        SetEndRounded(self, _arg)

        Parameters
        ----------
        _arg: bool

        """
        return _itkTubeSpatialObjectPython.itkTubeSpatialObject2_SetEndRounded(self, _arg)

    def GetEndRounded(self):
        r"""GetEndRounded(self) -> bool"""
        return _itkTubeSpatialObjectPython.itkTubeSpatialObject2_GetEndRounded(self)

    def EndRoundedOn(self):
        r"""EndRoundedOn(self)"""
        return _itkTubeSpatialObjectPython.itkTubeSpatialObject2_EndRoundedOn(self)

    def EndRoundedOff(self):
        r"""EndRoundedOff(self)"""
        return _itkTubeSpatialObjectPython.itkTubeSpatialObject2_EndRoundedOff(self)

    def ComputeTangentsAndNormals(self):
        r"""ComputeTangentsAndNormals(self) -> bool"""
        return _itkTubeSpatialObjectPython.itkTubeSpatialObject2_ComputeTangentsAndNormals(self)

    def RemoveDuplicatePointsInObjectSpace(self, minSpacingInObjectSpace=0):
        r"""
        RemoveDuplicatePointsInObjectSpace(self, minSpacingInObjectSpace=0) -> unsigned int

        Parameters
        ----------
        minSpacingInObjectSpace: double

        """
        return _itkTubeSpatialObjectPython.itkTubeSpatialObject2_RemoveDuplicatePointsInObjectSpace(self, minSpacingInObjectSpace)

    def SetParentPoint(self, _arg):
        r"""
        SetParentPoint(self, _arg)

        Parameters
        ----------
        _arg: int

        """
        return _itkTubeSpatialObjectPython.itkTubeSpatialObject2_SetParentPoint(self, _arg)

    def GetParentPoint(self):
        r"""GetParentPoint(self) -> int"""
        return _itkTubeSpatialObjectPython.itkTubeSpatialObject2_GetParentPoint(self)

    def SetRoot(self, _arg):
        r"""
        SetRoot(self, _arg)

        Parameters
        ----------
        _arg: bool

        """
        return _itkTubeSpatialObjectPython.itkTubeSpatialObject2_SetRoot(self, _arg)

    def GetRoot(self):
        r"""GetRoot(self) -> bool"""
        return _itkTubeSpatialObjectPython.itkTubeSpatialObject2_GetRoot(self)

    def RootOn(self):
        r"""RootOn(self)"""
        return _itkTubeSpatialObjectPython.itkTubeSpatialObject2_RootOn(self)

    def RootOff(self):
        r"""RootOff(self)"""
        return _itkTubeSpatialObjectPython.itkTubeSpatialObject2_RootOff(self)
    __swig_destroy__ = _itkTubeSpatialObjectPython.delete_itkTubeSpatialObject2

    @staticmethod
    def cast(obj):
        r"""
        cast(obj) -> itkTubeSpatialObject2

        Parameters
        ----------
        obj: itkLightObject *

        """
        return _itkTubeSpatialObjectPython.itkTubeSpatialObject2_cast(obj)

    def New(*args, **kargs):
        """New() -> itkTubeSpatialObject2

        Create a new object of the class itkTubeSpatialObject2 and set the input and the parameters if some
        named or non-named arguments are passed to that method.

        New() tries to assign all the non named parameters to the input of the new objects - the
        first non named parameter in the first input, etc.

        The named parameters are used by calling the method with the same name prefixed by 'Set'.

        Ex:

          itkTubeSpatialObject2.New(reader, threshold=10)

        is (most of the time) equivalent to:

          obj = itkTubeSpatialObject2.New()
          obj.SetInput(0, reader.GetOutput())
          obj.SetThreshold(10)
        """
        obj = itkTubeSpatialObject2.__New_orig__()
        from itk.support import template_class
        template_class.New(obj, *args, **kargs)
        return obj
    New = staticmethod(New)


# Register itkTubeSpatialObject2 in _itkTubeSpatialObjectPython:
_itkTubeSpatialObjectPython.itkTubeSpatialObject2_swigregister(itkTubeSpatialObject2)

def itkTubeSpatialObject3_New():
    return itkTubeSpatialObject3.New()

class itkTubeSpatialObject3(itkPointBasedSpatialObjectTube3):
    r"""Proxy of C++ itkTubeSpatialObject3 class."""

    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")

    def __init__(self, *args, **kwargs):
        raise AttributeError("No constructor defined")
    __repr__ = _swig_repr

    @staticmethod
    def __New_orig__():
        r"""__New_orig__() -> itkTubeSpatialObject3_Pointer"""
        return _itkTubeSpatialObjectPython.itkTubeSpatialObject3___New_orig__()

    def Clone(self):
        r"""Clone(self) -> itkTubeSpatialObject3_Pointer"""
        return _itkTubeSpatialObjectPython.itkTubeSpatialObject3_Clone(self)

    def SetEndRounded(self, _arg):
        r"""
        SetEndRounded(self, _arg)

        Parameters
        ----------
        _arg: bool

        """
        return _itkTubeSpatialObjectPython.itkTubeSpatialObject3_SetEndRounded(self, _arg)

    def GetEndRounded(self):
        r"""GetEndRounded(self) -> bool"""
        return _itkTubeSpatialObjectPython.itkTubeSpatialObject3_GetEndRounded(self)

    def EndRoundedOn(self):
        r"""EndRoundedOn(self)"""
        return _itkTubeSpatialObjectPython.itkTubeSpatialObject3_EndRoundedOn(self)

    def EndRoundedOff(self):
        r"""EndRoundedOff(self)"""
        return _itkTubeSpatialObjectPython.itkTubeSpatialObject3_EndRoundedOff(self)

    def ComputeTangentsAndNormals(self):
        r"""ComputeTangentsAndNormals(self) -> bool"""
        return _itkTubeSpatialObjectPython.itkTubeSpatialObject3_ComputeTangentsAndNormals(self)

    def RemoveDuplicatePointsInObjectSpace(self, minSpacingInObjectSpace=0):
        r"""
        RemoveDuplicatePointsInObjectSpace(self, minSpacingInObjectSpace=0) -> unsigned int

        Parameters
        ----------
        minSpacingInObjectSpace: double

        """
        return _itkTubeSpatialObjectPython.itkTubeSpatialObject3_RemoveDuplicatePointsInObjectSpace(self, minSpacingInObjectSpace)

    def SetParentPoint(self, _arg):
        r"""
        SetParentPoint(self, _arg)

        Parameters
        ----------
        _arg: int

        """
        return _itkTubeSpatialObjectPython.itkTubeSpatialObject3_SetParentPoint(self, _arg)

    def GetParentPoint(self):
        r"""GetParentPoint(self) -> int"""
        return _itkTubeSpatialObjectPython.itkTubeSpatialObject3_GetParentPoint(self)

    def SetRoot(self, _arg):
        r"""
        SetRoot(self, _arg)

        Parameters
        ----------
        _arg: bool

        """
        return _itkTubeSpatialObjectPython.itkTubeSpatialObject3_SetRoot(self, _arg)

    def GetRoot(self):
        r"""GetRoot(self) -> bool"""
        return _itkTubeSpatialObjectPython.itkTubeSpatialObject3_GetRoot(self)

    def RootOn(self):
        r"""RootOn(self)"""
        return _itkTubeSpatialObjectPython.itkTubeSpatialObject3_RootOn(self)

    def RootOff(self):
        r"""RootOff(self)"""
        return _itkTubeSpatialObjectPython.itkTubeSpatialObject3_RootOff(self)
    __swig_destroy__ = _itkTubeSpatialObjectPython.delete_itkTubeSpatialObject3

    @staticmethod
    def cast(obj):
        r"""
        cast(obj) -> itkTubeSpatialObject3

        Parameters
        ----------
        obj: itkLightObject *

        """
        return _itkTubeSpatialObjectPython.itkTubeSpatialObject3_cast(obj)

    def New(*args, **kargs):
        """New() -> itkTubeSpatialObject3

        Create a new object of the class itkTubeSpatialObject3 and set the input and the parameters if some
        named or non-named arguments are passed to that method.

        New() tries to assign all the non named parameters to the input of the new objects - the
        first non named parameter in the first input, etc.

        The named parameters are used by calling the method with the same name prefixed by 'Set'.

        Ex:

          itkTubeSpatialObject3.New(reader, threshold=10)

        is (most of the time) equivalent to:

          obj = itkTubeSpatialObject3.New()
          obj.SetInput(0, reader.GetOutput())
          obj.SetThreshold(10)
        """
        obj = itkTubeSpatialObject3.__New_orig__()
        from itk.support import template_class
        template_class.New(obj, *args, **kargs)
        return obj
    New = staticmethod(New)


# Register itkTubeSpatialObject3 in _itkTubeSpatialObjectPython:
_itkTubeSpatialObjectPython.itkTubeSpatialObject3_swigregister(itkTubeSpatialObject3)

